==> flink-1.15.1-src.tgz: flink-1.15.1/flink-core/src/test/java/org/apache/flink/api/common/typeutils/base/array/PrimitiveArrayComparatorTestBase.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.flink.api.common.typeutils.base.array;

import org.apache.flink.api.common.typeinfo.PrimitiveArrayTypeInfo;
import org.apache.flink.api.common.typeutils.ComparatorTestBase;
import org.apache.flink.api.common.typeutils.TypeComparator;
import org.apache.flink.api.common.typeutils.TypeSerializer;

public abstract class PrimitiveArrayComparatorTestBase<T> extends ComparatorTestBase<T> {
    private PrimitiveArrayTypeInfo<T> info;

    public PrimitiveArrayComparatorTestBase(PrimitiveArrayTypeInfo<T> info) {
        this.info = info;
    }

    @Override
    protected TypeComparator<T> createComparator(boolean ascending) {
        return info.createComparator(ascending, null).duplicate();
    }

    @Override
    protected TypeSerializer<T> createSerializer() {
        return info.createSerializer(null);
    }
}

==> flink-1.17.2-src.tgz: flink-1.17.2/flink-core/src/test/java/org/apache/flink/api/common/typeutils/base/array/PrimitiveArrayComparatorTestBase.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.flink.api.common.typeutils.base.array;

import org.apache.flink.api.common.typeinfo.PrimitiveArrayTypeInfo;
import org.apache.flink.api.common.typeutils.ComparatorTestBase;
import org.apache.flink.api.common.typeutils.TypeComparator;
import org.apache.flink.api.common.typeutils.TypeSerializer;

abstract class PrimitiveArrayComparatorTestBase<T> extends ComparatorTestBase<T> {
    private PrimitiveArrayTypeInfo<T> info;

    public PrimitiveArrayComparatorTestBase(PrimitiveArrayTypeInfo<T> info) {
        this.info = info;
    }

    @Override
    protected TypeComparator<T> createComparator(boolean ascending) {
        return info.createComparator(ascending, null).duplicate();
    }

    @Override
    protected TypeSerializer<T> createSerializer() {
        return info.createSerializer(null);
    }
}
